#!/bin/bash
#
#////////////////////////////////////////////////////////////
#===========================================================
# DGCP by eSport-CMS - Installation automatique
# Version : 1.0
# Auteur : Guillaume RAYMOND / OpenAI
# Date de développement : 04/02/2024
# Date de modification : 04/02/2024
# Site web : https://esport-cms.net
# Support technique : https://esport-cms.net/forum
# Contact : hooxie@live.fr
#===========================================================

# Environment
LANG=fr_FR.UTF-8
clear

# Création des log d'installation de Left 4 Dead 2
LOG="/home/dgcp_installation_l4d2_esportcms.log"

# Création du répertoire gamesfiles dans /home/
echo -e "${GREEN}Création du répertoire /home/gamesfiles/...${NC}" | tee -a "$LOG"
mkdir -p /home/gamesfiles
if [ $? -ne 0 ]; then
    echo -e "${RED}Erreur lors de la création du répertoire /home/gamesfiles/. Veuillez vérifier les permissions.${NC}" | tee -a "$LOG"
    exit 1
fi

# Couleurs
GREEN='\033[0;32m'
RED='\033[0;31m'
NC='\033[0m' # No Color

# Demande de confirmation pour continuer
read -p "$(echo -e "${GREEN}Vous êtes sur le point d'installer les bibliothèques nécessaires pour la gestion du module DGCP by eSport-CMS, êtes-vous sûr de vouloir continuer ? (Oui ou Non)${NC} ")" confirmation
if [ "$confirmation" != "Oui" ] && [ "$confirmation" != "oui" ]; then
    echo -e "${RED}Installation annulée.${NC}"
    echo -e "Installation annulée." >> "$LOG"
    exit 0
fi

# Etape 1
echo -e "${GREEN}Etape 1 : Installation des bibliothèques nécessaires...${NC}" | tee -a "$LOG"
apt update && apt install -y software-properties-common && apt-add-repository -y non-free && dpkg --add-architecture i386 && apt install -y lib32gcc-s1
if [ $? -ne 0 ]; then
    echo -e "${RED}Erreur lors de l'installation des paquets. Voici la liste des paquets non installés :${NC}" | tee -a "$LOG"
    apt-cache policy software-properties-common non-free lib32gcc-s1 >> "$LOG"
    exit 1
fi

# Etape 2
echo -e "${GREEN}Etape 2 : Téléchargement et extraction de SteamCMD...${NC}" | tee -a "$LOG"
curl -sqL "https://steamcdn-a.akamaihd.net/client/installer/steamcmd_linux.tar.gz" | tar zxvf -
if [ $? -ne 0 ]; then
    echo -e "${RED}Erreur lors du téléchargement ou de l'extraction de SteamCMD.${NC}" | tee -a "$LOG"
    exit 1
fi

# Etape 3
echo -e "${GREEN}Etape 3 : Exécution de steam.sh et installation de Left 4 Dead 2...${NC}" | tee -a "$LOG"
./steamcmd.sh +force_install_dir /home/gamesfiles/l4d2/ +login anonymous +app_update 222860 validate +exit
if [ $? -ne 0 ]; then
    echo -e "${RED}Erreur lors de l'exécution de steam.sh ou de l'installation de Left 4 Dead 2.${NC}" | tee -a "$LOG"
    exit 1
fi

echo -e "${GREEN}Installation terminée avec succès.${NC}" | tee -a "$LOG"
echo -e "-------------------------------" | tee -a "$LOG"
echo -e "${GREEN}Vous pouvez retrouver les log d'installation depuis le fichier : dgcp_installation_l4d2_esportcms.log dans le repertoire /home/.${NC}" | tee -a "$LOG"
echo -e "-------------------------------" | tee -a "$LOG"
echo -e "${GREEN}eSport-CMS vous remercie pour votre confiance.${NC}" | tee -a "$LOG"
exit 0